@@ -1,4 +1,4 @@
-ratiocalc <- function (
+ratiocalc <- function(
 data, 
 group = NULL, 
 which.eff = c("sig", "sli", "exp"),
@@ -7,10 +7,11 @@ type.eff = c("individual", "mean.single", "median.single",
 which.cp = c("cpD2", "cpD1", "cpE", "cpR", "cpT", "Cy0"), 
 ...)
 {      
-    if (class(data) != "pcrbatch")
+    if (class(data)[2] != "pcrbatch")
         stop("data is not of class 'pcrbatch'!")
     if (is.null(group))
         stop("Please define 'group'!")
+    if (length(attr(data, "fail")) > 0) group <- group[-attr(data, "fail")]    
     if (length(group) != ncol(data) - 1)
         stop("Length of 'group' and 'data' do not match!")
     if (is.numeric(which.eff))
@@ -18,31 +19,40 @@ which.cp = c("cpD2", "cpD1", "cpE", "cpR", "cpT", "Cy0"),
     else which.eff <- match.arg(which.eff)
     which.cp <- match.arg(which.cp)
     type.eff <- match.arg(type.eff)   
-    DATA <- data[, -1]
+    DATA <- data[, -1]     
     cpDat <- ts()
-    effDat <- ts()
+    effDat <- ts()      
     cpNames <- NULL
     effNames <- NULL
     PATTERN <- unique(group)
+    
     if (all(regexpr("rs", group, perl = TRUE) == -1))
         refNo <- TRUE
-    else refNo <- FALSE
+    else refNo <- FALSE   
+    
+    REPS <- lapply(PATTERN, function(x) which(x == group))
+    NREPS <- sapply(REPS, function(x) length(x))           
+    if (!all(NREPS > 1)) type.eff <- "individual"    
+    
     for (i in 1:length(PATTERN)) {
-        WHICH <- which(group == PATTERN[i])
-        cpSEL <- which(data[, 1] == paste("sig.", which.cp, sep = ""))
-        effSEL <- which(data[, 1] == paste(which.eff, ".eff", sep = ""))
-        tempCP <- as.numeric(DATA[cpSEL, WHICH])
-        tempEff <- as.numeric(DATA[effSEL, WHICH])
-        if (is.numeric(which.eff))
-            tempEff <- rep(which.eff, length(WHICH))
-        cpDat <- cbind(cpDat, ts(tempCP))
-        effDat <- cbind(effDat, ts(tempEff))
-        cpNames <- c(cpNames, paste("cp.", PATTERN[i], sep = ""))
-        effNames <- c(effNames, paste("eff.", PATTERN[i], sep = ""))
-    }
+      WHICH <- which(group == PATTERN[i]) 
+      cpSEL <- which(data[, 1] == paste("sig.", which.cp, sep = ""))          
+      effSEL <- which(data[, 1] == paste(which.eff, ".eff", sep = ""))        
+      if (length(WHICH) != 1) tempCP <- as.numeric(t(DATA[cpSEL, WHICH])) else tempCP <- as.numeric(as.vector(DATA[cpSEL, WHICH]))     
+      if (length(WHICH) != 1) tempEff <- as.numeric(t(DATA[effSEL, WHICH])) else tempEff <- as.numeric(as.vector(DATA[effSEL, WHICH]))       
+      if (is.numeric(which.eff)) tempEff <- rep(which.eff, length(WHICH))
+      cpDat <- cbind(cpDat, ts(tempCP))
+      effDat <- cbind(effDat, ts(tempEff))
+      cpNames <- c(cpNames, paste("cp.", PATTERN[i], sep = ""))
+      effNames <- c(effNames, paste("eff.", PATTERN[i], sep = ""))
+    }      
 
+    ####
+    effDat <- effDat
+    cpDat <- cpDat      
+        
     cpDat <- cpDat[, -1]
-    effDat <- effDat[, -1]
+    effDat <- effDat[, -1]                 
 
     if (is.numeric(which.eff))
         type.eff <- "individual"
@@ -66,8 +76,8 @@ which.cp = c("cpD2", "cpD1", "cpE", "cpR", "cpT", "Cy0"),
     cpDat <- matrix(cpDat, ncol = length(cpNames))
     effDat <- matrix(effDat, ncol = length(effNames))
     
-    allDat <- cbind(cpDat, effDat)
-    colnames(allDat) <- c(cpNames, effNames)        
+    allDat <- cbind(cpDat, effDat)     
+    colnames(allDat) <- c(cpNames, effNames)    
     
     if (refNo) {
       EXPR <- expression(eff.gc^cp.gc/eff.gs^cp.gs)
